<?php

namespace B2buy\Support\Policies;

use Litepie\User\Contracts\UserPolicy;
use B2buy\Support\Models\Support;

class SupportPolicy
{

    /**
     * Determine if the given user can view the support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function view(UserPolicy $user, Support $support)
    {
        if ($user->canDo('support.support.view') && $user->isAdmin()) {
            return true;
        }

        return $support->user_id == user_id() && $support->user_type == user_type();
    }

    /**
     * Determine if the given user can create a support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('support.support.create');
    }

    /**
     * Determine if the given user can update the given support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function update(UserPolicy $user, Support $support)
    {
        if ($user->canDo('support.support.edit') && $user->isAdmin()) {
            return true;
        }

        return $support->user_id == user_id() && $support->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Support $support)
    {
        return $support->user_id == user_id() && $support->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Support $support)
    {
        if ($user->canDo('support.support.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given support.
     *
     * @param UserPolicy $user
     * @param Support $support
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Support $support)
    {
        if ($user->canDo('support.support.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
